@@ -2,7 +2,6 @@ from pkg_resources import iter_entry_points
 
 from .version import _warn_if_setuptools_outdated
 from .utils import do
-from .discover import iter_matching_entrypoints
 from . import get_version
 
 
@@ -14,12 +13,7 @@ def version_keyword(dist, keyword, value):
         value = {}
     if getattr(value, "__call__", None):
         value = value()
-    # this piece of code is a hack to counter the mistake in root finding
-    matching_fallbacks = iter_matching_entrypoints(
-        ".", "setuptools_scm.parse_scm_fallback"
-    )
-    if any(matching_fallbacks):
-        value.pop("root", None)
+
     dist.metadata.version = get_version(**value)
 
 
